Real goto module for python.

Installation:
  >pip install goto-module
  

Usage:
  >from goto import goto 

  >print("Hello World")

  >#("hi")

  >print("hello")

  >goto("hi")

Output:
  >Hello World

  >hello

  >hello

  >hello

  >hello


  >hello

  >........

Note:
  The comments value should be unique like here it is ("hi") and should not be part of any other word or function.